@@ -5,4 +5,4 @@ from event_sourcery.interfaces.event import Event
 
 class Subscriber(Protocol):
     def __call__(self, event: Event) -> None:
-        ...
+        pass
